@@ -615,7 +615,7 @@ class QCirc(ctypes.Structure):
     def merge(self, qc):
         """
         merge quantum circuit.
-
+n
         Parameters
         ----------
         qc : instance of QCirc
@@ -944,7 +944,9 @@ class QCirc(ctypes.Structure):
         qcirc = cls()
 
         TRY_MAX = 10  # for random generation
-        for _ in range(gate_num):
+        max_q = -1
+        gate_count = 0
+        while gate_count < gate_num or max_q < qubit_num - 1:
             r = random.random()
             kind = None
             for i, p in enumerate(plist):
@@ -957,6 +959,8 @@ class QCirc(ctypes.Structure):
             if term_num == 1 and para_num == 0:    # 1-qubit gate
                 q0 = random.randint(0, qubit_num - 1)
                 qcirc.append_gate(kind, [q0])
+                max_q = max(max_q, q0)
+                gate_count += 1
             elif term_num == 1 and para_num == 1:  # 1-qubit and 1-parameter gate
                 q0 = random.randint(0, qubit_num - 1)
                 if phase is None:
@@ -966,6 +970,8 @@ class QCirc(ctypes.Structure):
                 else:
                     p = random.choice(phase)
                 qcirc.append_gate(kind, [q0], para=[p, 0., 0.])
+                max_q = max(max_q, q0)
+                gate_count += 1
             elif term_num == 2 and para_num == 0:  # 2-qubit gate
                 q0 = random.randint(0, qubit_num - 1)
                 q1 = random.randint(0, qubit_num - 1)
@@ -977,6 +983,8 @@ class QCirc(ctypes.Structure):
                     raise ValueError(("can't generate qubit id for '{}' gate."
                                       .format(cfg.GATE_STRING[kind])))
                 qcirc.append_gate(kind, [q0, q1])
+                max_q = max(max_q, q0, q1)
+                gate_count += 1
             elif term_num == 2 and para_num == 1:  # 2-qubit and 1-parameter gate
                 q0 = random.randint(0, qubit_num - 1)
                 q1 = random.randint(0, qubit_num - 1)
@@ -994,10 +1002,16 @@ class QCirc(ctypes.Structure):
                 else:
                     p = random.choice(phase)
                 qcirc.append_gate(kind, [q0, q1], para=[p, 0., 0.])
+                max_q = max(max_q, q0, q1)
+                gate_count += 1
             else:
                 raise ValueError(("gate of term_num={}, param_num={} is not supported"
                                   .format(term_num, para_num)))
 
+        # delete extra gates
+        for _ in range(gate_count - gate_num):
+            qcirc.pop_gate()
+
         return qcirc
 
     def to_pyzx(self):
@@ -1169,6 +1183,34 @@ class QCirc(ctypes.Structure):
         qc_pair = (qc_unitary, qc_non_unitary)
         return qc_pair
 
+    def all_gates_measurement(self):
+        """
+        gates of the qcirc are all measurement
+
+        Parameters
+        ----------
+        None
+
+        Returns
+        -------
+        ans : bool
+            True if all gates are measurement, False if otherwise
+        """
+        if self.kind_first() is None:
+            return False
+        
+        ans = True
+        qcirc = self.clone()
+        while True:
+            kind = qcirc.kind_first()
+            if kind is None:
+                break
+            (kind, qid, para, c, ctrl) = qcirc.pop_gate()
+            if kind is not cfg.MEASURE:
+                ans = False
+                break
+        return ans
+
     def __del__(self):
 
         qcirc_free(self)
