@@ -726,6 +726,7 @@ class Stabilizer(ctypes.Structure):
         """
         pauli_list = pp.pauli_list
         qid = pp.qid
+        factor = pp.factor
 
         if ctrl is None:
             for q, pauli in zip(qid, pauli_list):
@@ -751,6 +752,13 @@ class Stabilizer(ctypes.Structure):
                 else:
                     continue
 
+            if factor == -1.+0.j:
+                self.z(ctrl)
+            elif factor == 0.+1.j:
+                self.s(ctrl)
+            elif factor == 0.-1.j:
+                self.s_dg(ctrl)
+
         return self
 
     def __del__(self):
